@@ -13,6 +13,7 @@ import schedule
 import time
 from datetime import datetime
 import logging
+import traceback
 import sys
 import os
 
@@ -319,10 +320,11 @@ class StateWatcher(models.Model):
             logging.warning(
                 f"{ct} StateWatcher({self}).update failed with exception: \n"
                 f"{exc_type.__name__} in {fname} at line {exc_tb.tb_lineno}\n"
-                f"{exc}"
+                f"{traceback.format_exc()}"
             )
 
     def refresh(self):
+        self = StateWatcher.objects.get(id=self.id)
         changes = self.update()
         if changes:
             try:
@@ -334,7 +336,7 @@ class StateWatcher(models.Model):
                 logging.warning(
                     f"{ct} StateWatcher({self}).refresh failed with "
                     f"exception: \n{exc_type.__name__} in {fname} at line"
-                    f" {exc_tb.tb_lineno}\n {exc}"
+                    f" {exc_tb.tb_lineno}\n{traceback.format_exc()}"
                 )
 
     @classmethod
